##  Overview
The AI agent extension to the meta model enables you to model and govern your organization's AI agents and MCP servers to track the adoption of your agentic AI strategy. The extension provides a set of dedicated attributes and fact sheet subtypes.
Activating the AI agent extension is required to discover your AI agents and use the AI agent hub features. For detailed information, see [AI Agent Hub](https://help.sap.com/docs/leanix/ea/ai-agent-hub?locale=en-US&state=PRODUCTION&version=CLOUD "Discover and manage AI agents across the organization.").
